function [Vnode,Mnode,Vdc,Mdc,Vcampled,Mcampled,uf,MaxAc,tf]=DynamicLoad(kkhf,mm,sdof,nnode,freq,vecfreq,kk,Bottom,Wind,Wave,lengthvector,...
    rna,wdepth,Dtow,leng,nelmp,nbcd,DataGr,kmg,lengthvectormp,LaboveG,LbelowG,Ground,Th0,Tmax,DataCab,kcab,Cable)

%  Function Description:
%This function is used to introduce the initial data from wind and waves,
%gets the solution to the dynamic equation from myode.m and joins all the
%natural frequencies analyzed to obtain the final displacements, velocities
%and accelerations in the structure and the reactions of shear forces and
%bending moments in each node along the time selected (720s)

%%%  Input Variables Description: %%%
% damp= Damping ratio (percentage of the critical)
% tf=time of simulation (720s recommended)
% RelTol=1e-3; %Error for the ode (these are the default options but can be changed)
% AbsTol=1e-6; %Error for the ode (these are the default options but can be changed)
% Windfile=(Wind 08 - WindE08 - Wind 14 - WindE14 - Wind 20 - WindE20 - Wind Ex)
% Hs=Significant wave height (m)
% T=Period of the wave (s)
% nplot=selection of the node to show the displacements at that node


%%%%%% Parameters before the simulation
damp=0.01; % Damping of 1% of the critical

tf=720; %time of simulation

tspan=0:0.1:tf;
y0=zeros(1,2); %initial conditions
y0(1)=0;       
y0(2)=0;
RelTol=1e-3; %Error for the ode (these are the default options)
AbsTol=1e-6;

%%%%%%%%% Wind
Windfile='Wind Ex'; %%% Introduce the wind file (Wind 08 - WindE08 - Wind 14 - WindE14 - Wind 20 - WindE20 - Wind Ex)

if Windfile=='Wind Ex' %Ex=Extreme
    vo=42.73; %m/s Return period of 50 years
else
  vo=Windfile(end-1:end);
  vo=str2double(vo);  
end
A=xlsread('ForcesWindFinal',Windfile,'G3:I24004'); %Force from ASHES software at the top (time,shear,moment)(200s->I6670)(720s->I24004)(0s->G3)
A=A(1:3:end,:); %Taking data each 0.09s

%%%Wave Load
Hs=9.4; %Significant wave height for 50 years return period (9.4) or another
T=11.1*(Hs/9.81)^0.5; %Period between 11.1 and 14.3 *(H/9.81)^0.5.--> 11.1 suggested to obtain the most critical load from the wave.


aw=Hs/2; %Amplitude of the wave
wf=2*pi/T; %Radian frequency
L=1:10:1000; %Wave length under 1000m (otherwise-->change)
gw=wf^2-9.81*(2*pi./L).*tanh(wdepth*2*pi./L);%Dispersion Relation
Lw=interp1(gw,L,0);
kw=2*pi/Lw; %Wave number

nplot=nnode; %selection of the node to show the displacements at that node

%Natural frequencies info for clamped bottom
freqm1=freq(nbcd+1);
freqm2=freq(nbcd+2);
freqm3=freq(nbcd+3);
vecf1=vecfreq(:,nbcd+1);
vecf2=vecfreq(:,nbcd+2);
vecf3=vecfreq(:,nbcd+3);

%%%%%%Solving the ODE of second order
opts = odeset('RelTol',RelTol,'AbsTol',AbsTol); % Changing the error thresholds using odeset.

%%%Mode 1
ode =@(t,y) myode(t,y,mm,vecf1,freqm1,tf,nnode,A,damp,Th0,Tmax,DataCab,kcab,Cable,...
    rna,vo,aw,kw,wf,wdepth,lengthvector,Dtow,leng,nelmp,DataGr,kmg,lengthvectormp,LaboveG,LbelowG,Ground,Wind,Wave);
sol1=ode45(ode,tspan,y0,opts);
[y1,yd] = deval(sol1,tspan);

y1=y1';
a1=yd(2,:)';

%%%Mode 2
ode=@(t,y) myode(t,y,mm,vecf2,freqm2,tf,nnode,A,damp,Th0,Tmax,DataCab,kcab,Cable,...
    rna,vo,aw,kw,wf,wdepth,lengthvector,Dtow,leng,nelmp,DataGr,kmg,lengthvectormp,LaboveG,LbelowG,Ground,Wind,Wave);
sol2=ode45(ode,tspan,y0,opts);
[y2,yd] = deval(sol2,tspan);

y2=y2';
a2=yd(2,:)';

%%%Mode 3
ode=@(t,y) myode(t,y,mm,vecf3,freqm3,tf,nnode,A,damp,Th0,Tmax,DataCab,kcab,Cable,...
    rna,vo,aw,kw,wf,wdepth,lengthvector,Dtow,leng,nelmp,DataGr,kmg,lengthvectormp,LaboveG,LbelowG,Ground,Wind,Wave);
sol3=ode45(ode,tspan,y0,opts);
[y3,yd] = deval(sol3,tspan);

y3=y3';
a3=yd(2,:)';

%%%%%
t=tspan';
u1=zeros(size(t,1),sdof);
u2=zeros(size(t,1),sdof);
u3=zeros(size(t,1),sdof);
v1=zeros(size(t,1),sdof);
v2=zeros(size(t,1),sdof);
v3=zeros(size(t,1),sdof);
ac1=zeros(size(t,1),sdof);
ac2=zeros(size(t,1),sdof);
ac3=zeros(size(t,1),sdof);
for i=1:sdof
    u1(:,i)=vecf1(i)*y1(:,1); %displacements and rotations for the mode 1
    v1(:,i)=vecf1(i)*y1(:,2); %velocities for the mode 1
    ac1(:,i)=vecf1(i)*a1(:,1); %acceleration for the mode 1
    u2(:,i)=vecf2(i)*y2(:,1);
    v2(:,i)=vecf2(i)*y2(:,2);
    ac2(:,i)=vecf2(i)*a2(:,1);
    u3(:,i)=vecf3(i)*y3(:,1);
    v3(:,i)=vecf3(i)*y3(:,2);
    ac3(:,i)=vecf3(i)*a3(:,1);
end

%Adding the first modes of vibration
uf=u1+u2+u3;
vf=v1+v2+v3;
acf=ac1+ac2+ac3;
%Removing the first 120 seconds of simulation
uf=uf(1201:1:end,:);
vf=vf(1201:1:end,:);
acf=acf(1201:1:end,:);
t=t(1201:1:end);

%%%%%%%%%%%%%%
fig=figure; %%%Comparation of displacement, speed and acceleration at the top
set(fig,'name','Comparation of displacements, speeds and accelerations at the top','numbertitle','off')
subplot(3,1,1) 
plot(t,uf(:,sdof-1),'r') ;
grid on
ylabel('uf (m)')
title('Displacements at the top')

subplot(3,1,2) 
plot(t,vf(:,sdof-1),'b') ;
grid on
ylabel('vf (m/s)')
title('Speeds at the top')

subplot(3,1,3) 
plot(t,acf(:,sdof-1),'y') ;
grid on
xlabel('t(s)')
ylabel('af (m/s2)')
title('Accelerations at the top')
%%%%%%%%%%%%%%

MaxAc=max(abs(acf(:,sdof-1)));% Max acceleration at the top
if max(abs(acf(:,sdof-1)))>0.6*9.81
    if max(abs(acf(:,sdof-1)))>0.3*9.81
  disp(['The acceleration of the tower at the top is above 0.3*g(m/s2): ' num2str(max(abs(acf(:,sdof-1))))])  
    else
  disp(['The acceleration of the tower at the top is above 0.6*g(m/s2): ' num2str(max(abs(acf(:,sdof-1))))])
    end
end

if max(abs(uf(:,sdof)))*360/(2*pi)>15 %maximum tilt below 15 deg (for the extreme case)
    if max(abs(uf(:,sdof)))*360/(2*pi)>5 %maximum tilt below 5 deg (for the operational case)
  disp(['The tilt at the top of the tower is above 5: ' num2str(max(abs(uf(:,sdof)))*360/(2*pi))])  %Initial tilt not included
    else
  disp(['The tilt at the top of the tower is above 15: ' num2str(max(abs(uf(:,sdof)))*360/(2*pi))])  %Initial tilt not included
    end
end

%%%%%%%
%%%%% Loads and Bending moments

R=kkhf*uf'; %Using the stiffness matrix which includes the higher influence of bending strain energy than shear strain energy (slender beam).


Vnode=R(1:2:end,:);
Mnode=-R(2:2:end,:);

Vcampled=zeros(1,size(t,1));
Mcampled=zeros(1,size(t,1));
for i=1:nnode
    Vcampled=Vcampled+Vnode(i,:);
    Mcampled=Mcampled+Mnode(i,:);
end


%%%%%%%%%%%%%

figure;
plot(t,uf(:,nplot*2-1),'r')
grid on
xlabel('t(s)')
ylabel('uf (m)')
title('Example of displacements at the node selected')

%Maximum reactions at the base for the campled solution without ground
if Bottom=='C' && Ground=='N'
h=figure;
plot(t,Vcampled)
grid on
title('Force reaction')
xlabel('Time(s)');
ylabel('Force (N)');

Vdc=max(abs(Vcampled));

h=figure;
plot(t,Mcampled)
grid on
title('Bending moment reaction')
xlabel('Time(s)');
ylabel('Bending moment (N*m)');

Mdc=max(abs(Mcampled));
else
Vdc=0;
Vcampled=0;
Mdc=0;
Mcampled=0;
end
end
